use clap::Parser;
use colored::Colorize;
use crate::commands::Cli;
use log::{debug, info, SetLoggerError, trace};
use std::env;

mod commands;
mod package;

fn main() {
    setup_logger().expect("Unable to setup logger.");

    trace!("Parsing command line arguments...");
    let c = Cli::parse();
    debug!("Command line arguments parsed.");

    trace!("Executing command...");
    c.command.execute();
    debug!("Command executed.");

    trace!("Exiting...");
    info!("Done.");
}

fn setup_logger() -> Result<(), SetLoggerError> {
    fern::Dispatch::new()
        .format(|out, message, record| {
            out.finish(format_args!(
                "{} {}",
                match record.level().to_string().chars().nth(0).unwrap_or('I') {
                    'T' => "##".cyan(),
                    'D' => "::".yellow(),
                    'E' | 'W' => "!!".red(),
                    _ => "**".blue(),
                },
                message.to_string().bright_white()
            ))
        })
        .level(env::var("PKGR_LOG_LEVEL").unwrap_or_else(|_| "info".to_string()).parse().unwrap_or(log::LevelFilter::Info))
        .chain(std::io::stdout())
        .apply()
}
